@@ -127,7 +127,7 @@ class uint_t(int_t):  # pylint: disable=invalid-name
     size = 1
 
     def __repr__(self):
-        return "0x{0:0{1}X} ({0})".format(self, self.size)
+        return "0x{0:0{1}X} ({0})".format(int(self), self.size)
 
 
 class int24_t(int_t):  # pylint: disable=invalid-name
